==> mit-scheme_7.7.90+20080130.orig.tar.gz: mit-scheme-7.7.90+20080130.orig/src/xml/ed-ffi.scm <==
#| -*-Scheme-*-

$Id: ed-ffi.scm,v 1.13 2008/01/30 20:02:42 cph Exp $

Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
    1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
    2006, 2007, 2008 Massachusetts Institute of Technology

This file is part of MIT/GNU Scheme.

MIT/GNU Scheme is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

MIT/GNU Scheme is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with MIT/GNU Scheme; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
USA.

|#

;;;; XML: Edwin buffer packaging info

(standard-scheme-find-file-initialization
 '#(("rdf-nt" (runtime rdf nt))
    ("rdf-struct" (runtime rdf structures))
    ("turtle" (runtime rdf turtle))
    ("xhtml" (runtime xml html))
    ("xhtml-entities" (runtime xml html))
    ("xml-chars" (runtime xml parser))
    ("xml-names" (runtime xml names))
    ("xml-rpc" (runtime xml xml-rpc))
    ("xml-struct" (runtime xml structure))
    ("xml-output" (runtime xml output))
    ("xml-parser" (runtime xml parser))))

==> mit-scheme-10.1.2.tar.gz: mit-scheme-10.1.2/src/xml/ed-ffi.scm <==
#| -*-Scheme-*-

Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
    1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
    2017, 2018 Massachusetts Institute of Technology

This file is part of MIT/GNU Scheme.

MIT/GNU Scheme is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

MIT/GNU Scheme is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with MIT/GNU Scheme; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
USA.

|#

;;;; XML: Edwin buffer packaging info

(standard-scheme-find-file-initialization
 '#(("rdf-nt" (runtime rdf nt))
    ("rdf-struct" (runtime rdf structures))
    ("turtle" (runtime rdf turtle))
    ("xhtml" (runtime xml html))
    ("xhtml-entities" (runtime xml html))
    ("xml-chars" (runtime xml parser))
    ("xml-names" (runtime xml names))
    ("xml-rpc" (runtime xml xml-rpc))
    ("xml-struct" (runtime xml structure))
    ("xml-output" (runtime xml output))
    ("xml-parser" (runtime xml parser))))
